pyproject_hooks: Wrappers to call pyproject.toml-based build backend hooks.
===========================================================================

Description
-----------

Wrappers to call pyproject.toml-based build backend hooks.

License
-------

Upstream Contact
----------------

https://pypi.org/project/pyproject_hooks/

